@@ -2,7 +2,7 @@
 Get all AWS tag filters returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.aws_integration_api import AWSIntegrationApi
 
 configuration = Configuration()
