@@ -2,7 +2,7 @@
 List all AWS Logs integrations returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.aws_logs_integration_api import AWSLogsIntegrationApi
 
 configuration = Configuration()
