@@ -2,7 +2,7 @@
 List all Azure integrations returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.azure_integration_api import AzureIntegrationApi
 
 configuration = Configuration()
