@@ -2,7 +2,7 @@
 Update an Azure integration returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.azure_integration_api import AzureIntegrationApi
 from datadog_api_client.v1.model.azure_account import AzureAccount
 
