@@ -2,7 +2,7 @@
 List all GCP integrations returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.gcp_integration_api import GCPIntegrationApi
 
 configuration = Configuration()
