@@ -33,6 +33,6 @@ body = MetricsPayload(
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = MetricsApi(api_client)
-    response = api_instance.submit_metrics(content_encoding=MetricContentEncoding("deflate"), body=body)
+    response = api_instance.submit_metrics(content_encoding=MetricContentEncoding.DEFLATE, body=body)
 
     print(response)
