@@ -16,7 +16,7 @@ from datadog_api_client.v1.model.monitor_type import MonitorType
 body = Monitor(
     name="Example-Create_a_metric_monitor_returns_OK_response",
     type=MonitorType.METRIC_ALERT,
-    query="avg(current_1d):avg:system.load.5{*} > 0.5",
+    query="avg(current_1mo):avg:system.load.5{*} > 0.5",
     message="some message Notify: @hipchat-channel",
     options=MonitorOptions(
         thresholds=MonitorThresholds(
