@@ -3,7 +3,7 @@ Get a synthetics monitor's details
 """
 
 from os import environ
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.monitors_api import MonitorsApi
 
 # there is a valid "synthetics_api_test" in the system
