@@ -7,6 +7,7 @@ from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.monitors_api import MonitorsApi
 from datadog_api_client.v1.model.monitor import Monitor
 from datadog_api_client.v1.model.monitor_options import MonitorOptions
+from datadog_api_client.v1.model.monitor_options_notification_presets import MonitorOptionsNotificationPresets
 from datadog_api_client.v1.model.monitor_thresholds import MonitorThresholds
 from datadog_api_client.v1.model.monitor_type import MonitorType
 from datadog_api_client.v1.model.on_missing_data_option import OnMissingDataOption
@@ -36,6 +37,7 @@ body = Monitor(
         notify_audit=False,
         notify_no_data=False,
         on_missing_data=OnMissingDataOption.SHOW_AND_NOTIFY_NO_DATA,
+        notification_preset_name=MonitorOptionsNotificationPresets.HIDE_HANDLES,
         renotify_interval=60,
         require_full_window=True,
         timeout_h=24,
