@@ -3,7 +3,7 @@ Get an API test result returns result with failure object
 """
 
 from os import environ
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.synthetics_api import SyntheticsApi
 
 # there is a "synthetics_api_test_with_wrong_dns" in the system
