@@ -2,7 +2,7 @@
 Add tags to a host returns "Created" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.tags_api import TagsApi
 from datadog_api_client.v1.model.host_tags import HostTags
 
