@@ -2,7 +2,7 @@
 Remove host tags returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.tags_api import TagsApi
 
 configuration = Configuration()
