@@ -2,7 +2,7 @@
 Get a list of Audit Logs events returns "OK" response
 """
 
-from datadog_api_client.v2 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v2.api.audit_api import AuditApi
 
 configuration = Configuration()
