@@ -11,7 +11,7 @@ from datadog_api_client.v2.model.incident_team_type import IncidentTeamType
 
 body = IncidentTeamCreateRequest(
     data=IncidentTeamCreateData(
-        type=IncidentTeamType("teams"),
+        type=IncidentTeamType.TEAMS,
         attributes=IncidentTeamCreateAttributes(
             name="Example-Create_a_new_incident_team_returns_CREATED_response",
         ),
