@@ -3,7 +3,7 @@ Delete an API key returns "No Content" response
 """
 
 from os import environ
-from datadog_api_client.v2 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v2.api.key_management_api import KeyManagementApi
 
 # there is a valid "api_key" in the system
