@@ -5,7 +5,6 @@ Create a detection rule with type 'impossible_travel' returns "OK" response
 from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi
 from datadog_api_client.v2.model.security_monitoring_rule_case_create import SecurityMonitoringRuleCaseCreate
-from datadog_api_client.v2.model.security_monitoring_rule_create_payload import SecurityMonitoringRuleCreatePayload
 from datadog_api_client.v2.model.security_monitoring_rule_detection_method import SecurityMonitoringRuleDetectionMethod
 from datadog_api_client.v2.model.security_monitoring_rule_evaluation_window import (
     SecurityMonitoringRuleEvaluationWindow,
@@ -21,14 +20,17 @@ from datadog_api_client.v2.model.security_monitoring_rule_options import Securit
 from datadog_api_client.v2.model.security_monitoring_rule_query_aggregation import (
     SecurityMonitoringRuleQueryAggregation,
 )
-from datadog_api_client.v2.model.security_monitoring_rule_query_create import SecurityMonitoringRuleQueryCreate
 from datadog_api_client.v2.model.security_monitoring_rule_severity import SecurityMonitoringRuleSeverity
 from datadog_api_client.v2.model.security_monitoring_rule_type_create import SecurityMonitoringRuleTypeCreate
+from datadog_api_client.v2.model.security_monitoring_standard_rule_create_payload import (
+    SecurityMonitoringStandardRuleCreatePayload,
+)
+from datadog_api_client.v2.model.security_monitoring_standard_rule_query import SecurityMonitoringStandardRuleQuery
 
-body = SecurityMonitoringRuleCreatePayload(
+body = SecurityMonitoringStandardRuleCreatePayload(
     queries=[
-        SecurityMonitoringRuleQueryCreate(
-            aggregation=SecurityMonitoringRuleQueryAggregation("geo_data"),
+        SecurityMonitoringStandardRuleQuery(
+            aggregation=SecurityMonitoringRuleQueryAggregation.GEO_DATA,
             group_by_fields=[
                 "@usr.id",
             ],
@@ -40,7 +42,7 @@ body = SecurityMonitoringRuleCreatePayload(
     cases=[
         SecurityMonitoringRuleCaseCreate(
             name="",
-            status=SecurityMonitoringRuleSeverity("info"),
+            status=SecurityMonitoringRuleSeverity.INFO,
             notifications=[],
         ),
     ],
@@ -48,16 +50,16 @@ body = SecurityMonitoringRuleCreatePayload(
     message="test",
     is_enabled=True,
     options=SecurityMonitoringRuleOptions(
-        max_signal_duration=SecurityMonitoringRuleMaxSignalDuration(86400),
-        evaluation_window=SecurityMonitoringRuleEvaluationWindow(900),
-        keep_alive=SecurityMonitoringRuleKeepAlive(3600),
-        detection_method=SecurityMonitoringRuleDetectionMethod("impossible_travel"),
+        max_signal_duration=SecurityMonitoringRuleMaxSignalDuration.ONE_DAY,
+        evaluation_window=SecurityMonitoringRuleEvaluationWindow.FIFTEEN_MINUTES,
+        keep_alive=SecurityMonitoringRuleKeepAlive.ONE_HOUR,
+        detection_method=SecurityMonitoringRuleDetectionMethod.IMPOSSIBLE_TRAVEL,
         impossible_travel_options=SecurityMonitoringRuleImpossibleTravelOptions(
             baseline_user_locations=False,
         ),
     ),
     name="Example-Create_a_detection_rule_with_type_impossible_travel_returns_OK_response",
-    type=SecurityMonitoringRuleTypeCreate("log_detection"),
+    type=SecurityMonitoringRuleTypeCreate.LOG_DETECTION,
     tags=[],
     filters=[],
 )
