@@ -1,14 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.apm_stats_query_column_type import ApmStatsQueryColumnType
+    from datadog_api_client.v1.model.apm_stats_query_row_type import ApmStatsQueryRowType
+
+
 class ApmStatsQueryDefinition(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -35,7 +44,17 @@ class ApmStatsQueryDefinition(ModelNormal):
         "service": "service",
     }
 
-    def __init__(self_, env, name, primary_tag, row_type, service, *args, **kwargs):
+    def __init__(
+        self_,
+        env: str,
+        name: str,
+        primary_tag: str,
+        row_type: ApmStatsQueryRowType,
+        service: str,
+        columns: Union[List[ApmStatsQueryColumnType], UnsetType] = unset,
+        resource: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         The APM stats query for table and distributions widgets.
 
@@ -60,10 +79,12 @@ class ApmStatsQueryDefinition(ModelNormal):
         :param service: Service name.
         :type service: str
         """
+        if columns is not unset:
+            kwargs["columns"] = columns
+        if resource is not unset:
+            kwargs["resource"] = resource
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.env = env
         self_.name = name
         self_.primary_tag = primary_tag
