@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -26,7 +30,14 @@ class DistributionWidgetXAxis(ModelNormal):
         "scale": "scale",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        include_zero: Union[bool, UnsetType] = unset,
+        max: Union[str, UnsetType] = unset,
+        min: Union[str, UnsetType] = unset,
+        scale: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         X Axis controls for the distribution widget.
 
@@ -42,6 +53,12 @@ class DistributionWidgetXAxis(ModelNormal):
         :param scale: Specifies the scale type. Possible values are ``linear``.
         :type scale: str, optional
         """
+        if include_zero is not unset:
+            kwargs["include_zero"] = include_zero
+        if max is not unset:
+            kwargs["max"] = max
+        if min is not unset:
+            kwargs["min"] = min
+        if scale is not unset:
+            kwargs["scale"] = scale
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
