@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -24,7 +28,13 @@ class GraphSnapshot(ModelNormal):
         "snapshot_url": "snapshot_url",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        graph_def: Union[str, UnsetType] = unset,
+        metric_query: Union[str, UnsetType] = unset,
+        snapshot_url: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Object representing a graph snapshot.
 
@@ -39,6 +49,10 @@ class GraphSnapshot(ModelNormal):
         :param snapshot_url: URL of your `graph snapshot <https://docs.datadoghq.com/metrics/explorer/#snapshot>`_.
         :type snapshot_url: str, optional
         """
+        if graph_def is not unset:
+            kwargs["graph_def"] = graph_def
+        if metric_query is not unset:
+            kwargs["metric_query"] = metric_query
+        if snapshot_url is not unset:
+            kwargs["snapshot_url"] = snapshot_url
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
