@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -24,7 +28,13 @@ class HostMuteSettings(ModelNormal):
         "override": "override",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        end: Union[int, UnsetType] = unset,
+        message: Union[str, UnsetType] = unset,
+        override: Union[bool, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Combination of settings to mute a host.
 
@@ -37,6 +47,10 @@ class HostMuteSettings(ModelNormal):
         :param override: If true and the host is already muted, replaces existing host mute settings.
         :type override: bool, optional
         """
+        if end is not unset:
+            kwargs["end"] = end
+        if message is not unset:
+            kwargs["message"] = message
+        if override is not unset:
+            kwargs["override"] = override
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
