@@ -16,7 +16,7 @@ class HourlyUsageAttributionUsageType(ModelSimple):
     """
     Supported products for hourly usage attribution requests.
 
-    :param value: Must be one of ["api_usage", "apm_fargate_usage", "apm_host_usage", "appsec_fargate_usage", "appsec_usage", "browser_usage", "container_usage", "cspm_containers_usage", "cspm_hosts_usage", "custom_timeseries_usage", "cws_containers_usage", "cws_hosts_usage", "dbm_hosts_usage", "dbm_queries_usage", "estimated_indexed_logs_usage", "estimated_ingested_logs_usage", "estimated_indexed_spans_usage", "estimated_ingested_spans_usage", "fargate_usage", "functions_usage", "indexed_logs_usage", "infra_host_usage", "invocations_usage", "npm_host_usage", "profiled_container_usage", "profiled_host_usage", "snmp_usage"].
+    :param value: Must be one of ["api_usage", "apm_fargate_usage", "apm_host_usage", "appsec_fargate_usage", "appsec_usage", "browser_usage", "container_excl_agent_usage", "container_usage", "cspm_containers_usage", "cspm_hosts_usage", "custom_timeseries_usage", "cws_containers_usage", "cws_hosts_usage", "dbm_hosts_usage", "dbm_queries_usage", "estimated_indexed_logs_usage", "estimated_ingested_logs_usage", "estimated_indexed_spans_usage", "estimated_ingested_spans_usage", "fargate_usage", "functions_usage", "infra_host_usage", "invocations_usage", "npm_host_usage", "profiled_container_usage", "profiled_host_usage", "snmp_usage", "estimated_rum_sessions_usage"].
     :type value: str
     """
 
@@ -27,6 +27,7 @@ class HourlyUsageAttributionUsageType(ModelSimple):
         "appsec_fargate_usage",
         "appsec_usage",
         "browser_usage",
+        "container_excl_agent_usage",
         "container_usage",
         "cspm_containers_usage",
         "cspm_hosts_usage",
@@ -41,13 +42,13 @@ class HourlyUsageAttributionUsageType(ModelSimple):
         "estimated_ingested_spans_usage",
         "fargate_usage",
         "functions_usage",
-        "indexed_logs_usage",
         "infra_host_usage",
         "invocations_usage",
         "npm_host_usage",
         "profiled_container_usage",
         "profiled_host_usage",
         "snmp_usage",
+        "estimated_rum_sessions_usage",
     }
     API_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
     APM_FARGATE_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
@@ -55,6 +56,7 @@ class HourlyUsageAttributionUsageType(ModelSimple):
     APPSEC_FARGATE_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
     APPSEC_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
     BROWSER_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
+    CONTAINER_EXCL_AGENT_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
     CONTAINER_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
     CSPM_CONTAINERS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
     CSPM_HOSTS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
@@ -69,13 +71,13 @@ class HourlyUsageAttributionUsageType(ModelSimple):
     ESTIMATED_INGESTED_SPANS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
     FARGATE_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
     FUNCTIONS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
-    INDEXED_LOGS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
     INFRA_HOST_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
     INVOCATIONS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
     NPM_HOST_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
     PROFILED_CONTAINER_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
     PROFILED_HOST_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
     SNMP_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
+    ESTIMATED_RUM_SESSIONS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
 
     @cached_property
     def openapi_types(_):
@@ -90,6 +92,9 @@ HourlyUsageAttributionUsageType.APM_HOST_USAGE = HourlyUsageAttributionUsageType
 HourlyUsageAttributionUsageType.APPSEC_FARGATE_USAGE = HourlyUsageAttributionUsageType("appsec_fargate_usage")
 HourlyUsageAttributionUsageType.APPSEC_USAGE = HourlyUsageAttributionUsageType("appsec_usage")
 HourlyUsageAttributionUsageType.BROWSER_USAGE = HourlyUsageAttributionUsageType("browser_usage")
+HourlyUsageAttributionUsageType.CONTAINER_EXCL_AGENT_USAGE = HourlyUsageAttributionUsageType(
+    "container_excl_agent_usage"
+)
 HourlyUsageAttributionUsageType.CONTAINER_USAGE = HourlyUsageAttributionUsageType("container_usage")
 HourlyUsageAttributionUsageType.CSPM_CONTAINERS_USAGE = HourlyUsageAttributionUsageType("cspm_containers_usage")
 HourlyUsageAttributionUsageType.CSPM_HOSTS_USAGE = HourlyUsageAttributionUsageType("cspm_hosts_usage")
@@ -112,10 +117,12 @@ HourlyUsageAttributionUsageType.ESTIMATED_INGESTED_SPANS_USAGE = HourlyUsageAttr
 )
 HourlyUsageAttributionUsageType.FARGATE_USAGE = HourlyUsageAttributionUsageType("fargate_usage")
 HourlyUsageAttributionUsageType.FUNCTIONS_USAGE = HourlyUsageAttributionUsageType("functions_usage")
-HourlyUsageAttributionUsageType.INDEXED_LOGS_USAGE = HourlyUsageAttributionUsageType("indexed_logs_usage")
 HourlyUsageAttributionUsageType.INFRA_HOST_USAGE = HourlyUsageAttributionUsageType("infra_host_usage")
 HourlyUsageAttributionUsageType.INVOCATIONS_USAGE = HourlyUsageAttributionUsageType("invocations_usage")
 HourlyUsageAttributionUsageType.NPM_HOST_USAGE = HourlyUsageAttributionUsageType("npm_host_usage")
 HourlyUsageAttributionUsageType.PROFILED_CONTAINER_USAGE = HourlyUsageAttributionUsageType("profiled_container_usage")
 HourlyUsageAttributionUsageType.PROFILED_HOST_USAGE = HourlyUsageAttributionUsageType("profiled_host_usage")
 HourlyUsageAttributionUsageType.SNMP_USAGE = HourlyUsageAttributionUsageType("snmp_usage")
+HourlyUsageAttributionUsageType.ESTIMATED_RUM_SESSIONS_USAGE = HourlyUsageAttributionUsageType(
+    "estimated_rum_sessions_usage"
+)
