@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,10 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.i_frame_widget_definition_type import IFrameWidgetDefinitionType
+
+
 class IFrameWidgetDefinition(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -24,7 +30,7 @@ class IFrameWidgetDefinition(ModelNormal):
         "url": "url",
     }
 
-    def __init__(self_, type, url, *args, **kwargs):
+    def __init__(self_, type: IFrameWidgetDefinitionType, url: str, **kwargs):
         """
         The iframe widget allows you to embed a portion of any other web page on your dashboard. Only available on FREE layout dashboards.
 
@@ -36,7 +42,5 @@ class IFrameWidgetDefinition(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.type = type
         self_.url = url
