@@ -1,6 +1,7 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
 
 from datadog_api_client.model_utils import (
@@ -10,7 +11,7 @@ from datadog_api_client.model_utils import (
 
 
 class LogsProcessor(ModelComposed):
-    def __init__(self_, *args, **kwargs):
+    def __init__(self, **kwargs):
         """
         Definition of a logs processor.
 
@@ -87,11 +88,12 @@ class LogsProcessor(ModelComposed):
         :param lookup_table: Mapping table of values for the source attribute and their associated target attribute values,
             formatted as `["source_key1,target_value1", "source_key2,target_value2"]`
         :type lookup_table: [str]
+
+        :param lookup_enrichment_table: Name of the Reference Table for the source attribute and their associated target attribute values.
+        :type lookup_enrichment_table: str
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
     @cached_property
     def _composed_schemas(_):
         # we need this here to make our import statements work
@@ -115,6 +117,7 @@ class LogsProcessor(ModelComposed):
         from datadog_api_client.v1.model.logs_pipeline_processor import LogsPipelineProcessor
         from datadog_api_client.v1.model.logs_geo_ip_parser import LogsGeoIPParser
         from datadog_api_client.v1.model.logs_lookup_processor import LogsLookupProcessor
+        from datadog_api_client.v1.model.reference_table_logs_lookup_processor import ReferenceTableLogsLookupProcessor
         from datadog_api_client.v1.model.logs_trace_remapper import LogsTraceRemapper
 
         return {
@@ -133,6 +136,7 @@ class LogsProcessor(ModelComposed):
                 LogsPipelineProcessor,
                 LogsGeoIPParser,
                 LogsLookupProcessor,
+                ReferenceTableLogsLookupProcessor,
                 LogsTraceRemapper,
             ],
         }
