@@ -1,14 +1,24 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.monitor_formula_and_function_event_aggregation import (
+        MonitorFormulaAndFunctionEventAggregation,
+    )
+
+
 class MonitorFormulaAndFunctionEventQueryDefinitionCompute(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -28,7 +38,13 @@ class MonitorFormulaAndFunctionEventQueryDefinitionCompute(ModelNormal):
         "metric": "metric",
     }
 
-    def __init__(self_, aggregation, *args, **kwargs):
+    def __init__(
+        self_,
+        aggregation: MonitorFormulaAndFunctionEventAggregation,
+        interval: Union[int, UnsetType] = unset,
+        metric: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Compute options.
 
@@ -41,8 +57,10 @@ class MonitorFormulaAndFunctionEventQueryDefinitionCompute(ModelNormal):
         :param metric: Measurable attribute to compute.
         :type metric: str, optional
         """
+        if interval is not unset:
+            kwargs["interval"] = interval
+        if metric is not unset:
+            kwargs["metric"] = metric
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.aggregation = aggregation
