@@ -1,15 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     none_type,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates
+
+
 class MonitorGroupSearchResult(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -44,7 +52,17 @@ class MonitorGroupSearchResult(ModelNormal):
         "status",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        group: Union[str, UnsetType] = unset,
+        group_tags: Union[List[str], UnsetType] = unset,
+        last_nodata_ts: Union[int, UnsetType] = unset,
+        last_triggered_ts: Union[int, none_type, UnsetType] = unset,
+        monitor_id: Union[int, UnsetType] = unset,
+        monitor_name: Union[str, UnsetType] = unset,
+        status: Union[MonitorOverallStates, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         A single monitor group search result.
 
@@ -69,6 +87,18 @@ class MonitorGroupSearchResult(ModelNormal):
         :param status: The different states your monitor can be in.
         :type status: MonitorOverallStates, optional
         """
+        if group is not unset:
+            kwargs["group"] = group
+        if group_tags is not unset:
+            kwargs["group_tags"] = group_tags
+        if last_nodata_ts is not unset:
+            kwargs["last_nodata_ts"] = last_nodata_ts
+        if last_triggered_ts is not unset:
+            kwargs["last_triggered_ts"] = last_triggered_ts
+        if monitor_id is not unset:
+            kwargs["monitor_id"] = monitor_id
+        if monitor_name is not unset:
+            kwargs["monitor_name"] = monitor_name
+        if status is not unset:
+            kwargs["status"] = status
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
