@@ -1,14 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.usage_attribution_aggregates import UsageAttributionAggregates
+    from datadog_api_client.v1.model.monthly_usage_attribution_pagination import MonthlyUsageAttributionPagination
+
+
 class MonthlyUsageAttributionMetadata(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -25,7 +34,12 @@ class MonthlyUsageAttributionMetadata(ModelNormal):
         "pagination": "pagination",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        aggregates: Union[UsageAttributionAggregates, UnsetType] = unset,
+        pagination: Union[MonthlyUsageAttributionPagination, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         The object containing document metadata.
 
@@ -35,6 +49,8 @@ class MonthlyUsageAttributionMetadata(ModelNormal):
         :param pagination: The metadata for the current pagination.
         :type pagination: MonthlyUsageAttributionPagination, optional
         """
+        if aggregates is not unset:
+            kwargs["aggregates"] = aggregates
+        if pagination is not unset:
+            kwargs["pagination"] = pagination
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
