@@ -29,6 +29,8 @@ class MonthlyUsageAttributionValues(ModelNormal):
             "appsec_usage": (float,),
             "browser_percentage": (float,),
             "browser_usage": (float,),
+            "container_excl_agent_percentage": (float,),
+            "container_excl_agent_usage": (float,),
             "container_percentage": (float,),
             "container_usage": (float,),
             "cspm_containers_percentage": (float,),
@@ -53,12 +55,12 @@ class MonthlyUsageAttributionValues(ModelNormal):
             "estimated_ingested_logs_usage": (float,),
             "estimated_ingested_spans_percentage": (float,),
             "estimated_ingested_spans_usage": (float,),
+            "estimated_rum_sessions_percentage": (float,),
+            "estimated_rum_sessions_usage": (float,),
             "fargate_percentage": (float,),
             "fargate_usage": (float,),
             "functions_percentage": (float,),
             "functions_usage": (float,),
-            "indexed_logs_percentage": (float,),
-            "indexed_logs_usage": (float,),
             "infra_host_percentage": (float,),
             "infra_host_usage": (float,),
             "invocations_percentage": (float,),
@@ -86,6 +88,8 @@ class MonthlyUsageAttributionValues(ModelNormal):
         "appsec_usage": "appsec_usage",
         "browser_percentage": "browser_percentage",
         "browser_usage": "browser_usage",
+        "container_excl_agent_percentage": "container_excl_agent_percentage",
+        "container_excl_agent_usage": "container_excl_agent_usage",
         "container_percentage": "container_percentage",
         "container_usage": "container_usage",
         "cspm_containers_percentage": "cspm_containers_percentage",
@@ -110,12 +114,12 @@ class MonthlyUsageAttributionValues(ModelNormal):
         "estimated_ingested_logs_usage": "estimated_ingested_logs_usage",
         "estimated_ingested_spans_percentage": "estimated_ingested_spans_percentage",
         "estimated_ingested_spans_usage": "estimated_ingested_spans_usage",
+        "estimated_rum_sessions_percentage": "estimated_rum_sessions_percentage",
+        "estimated_rum_sessions_usage": "estimated_rum_sessions_usage",
         "fargate_percentage": "fargate_percentage",
         "fargate_usage": "fargate_usage",
         "functions_percentage": "functions_percentage",
         "functions_usage": "functions_usage",
-        "indexed_logs_percentage": "indexed_logs_percentage",
-        "indexed_logs_usage": "indexed_logs_usage",
         "infra_host_percentage": "infra_host_percentage",
         "infra_host_usage": "infra_host_usage",
         "invocations_percentage": "invocations_percentage",
@@ -144,6 +148,8 @@ class MonthlyUsageAttributionValues(ModelNormal):
         appsec_usage: Union[float, UnsetType] = unset,
         browser_percentage: Union[float, UnsetType] = unset,
         browser_usage: Union[float, UnsetType] = unset,
+        container_excl_agent_percentage: Union[float, UnsetType] = unset,
+        container_excl_agent_usage: Union[float, UnsetType] = unset,
         container_percentage: Union[float, UnsetType] = unset,
         container_usage: Union[float, UnsetType] = unset,
         cspm_containers_percentage: Union[float, UnsetType] = unset,
@@ -168,12 +174,12 @@ class MonthlyUsageAttributionValues(ModelNormal):
         estimated_ingested_logs_usage: Union[float, UnsetType] = unset,
         estimated_ingested_spans_percentage: Union[float, UnsetType] = unset,
         estimated_ingested_spans_usage: Union[float, UnsetType] = unset,
+        estimated_rum_sessions_percentage: Union[float, UnsetType] = unset,
+        estimated_rum_sessions_usage: Union[float, UnsetType] = unset,
         fargate_percentage: Union[float, UnsetType] = unset,
         fargate_usage: Union[float, UnsetType] = unset,
         functions_percentage: Union[float, UnsetType] = unset,
         functions_usage: Union[float, UnsetType] = unset,
-        indexed_logs_percentage: Union[float, UnsetType] = unset,
-        indexed_logs_usage: Union[float, UnsetType] = unset,
         infra_host_percentage: Union[float, UnsetType] = unset,
         infra_host_usage: Union[float, UnsetType] = unset,
         invocations_percentage: Union[float, UnsetType] = unset,
@@ -227,6 +233,12 @@ class MonthlyUsageAttributionValues(ModelNormal):
         :param browser_usage: The synthetic browser test usage by tag(s).
         :type browser_usage: float, optional
 
+        :param container_excl_agent_percentage: The percentage of container usage without the Datadog Agent by tag(s).
+        :type container_excl_agent_percentage: float, optional
+
+        :param container_excl_agent_usage: The container usage without the Datadog Agent by tag(s).
+        :type container_excl_agent_usage: float, optional
+
         :param container_percentage: The percentage of container usage by tag(s).
         :type container_percentage: float, optional
 
@@ -299,6 +311,12 @@ class MonthlyUsageAttributionValues(ModelNormal):
         :param estimated_ingested_spans_usage: The estimated ingested spans usage by tag(s). This field is in private beta.
         :type estimated_ingested_spans_usage: float, optional
 
+        :param estimated_rum_sessions_percentage: The percentage of estimated rum sessions usage by tag(s). This field is in private beta.
+        :type estimated_rum_sessions_percentage: float, optional
+
+        :param estimated_rum_sessions_usage: The estimated rum sessions usage by tag(s). This field is in private beta.
+        :type estimated_rum_sessions_usage: float, optional
+
         :param fargate_percentage: The percentage of Fargate usage by tags.
         :type fargate_percentage: float, optional
 
@@ -311,12 +329,6 @@ class MonthlyUsageAttributionValues(ModelNormal):
         :param functions_usage: The Lambda function usage by tag(s).
         :type functions_usage: float, optional
 
-        :param indexed_logs_percentage: The percentage of indexed logs usage by tags.
-        :type indexed_logs_percentage: float, optional
-
-        :param indexed_logs_usage: The indexed logs usage by tags.
-        :type indexed_logs_usage: float, optional
-
         :param infra_host_percentage: The percentage of infrastructure host usage by tag(s).
         :type infra_host_percentage: float, optional
 
@@ -377,6 +389,10 @@ class MonthlyUsageAttributionValues(ModelNormal):
             kwargs["browser_percentage"] = browser_percentage
         if browser_usage is not unset:
             kwargs["browser_usage"] = browser_usage
+        if container_excl_agent_percentage is not unset:
+            kwargs["container_excl_agent_percentage"] = container_excl_agent_percentage
+        if container_excl_agent_usage is not unset:
+            kwargs["container_excl_agent_usage"] = container_excl_agent_usage
         if container_percentage is not unset:
             kwargs["container_percentage"] = container_percentage
         if container_usage is not unset:
@@ -425,6 +441,10 @@ class MonthlyUsageAttributionValues(ModelNormal):
             kwargs["estimated_ingested_spans_percentage"] = estimated_ingested_spans_percentage
         if estimated_ingested_spans_usage is not unset:
             kwargs["estimated_ingested_spans_usage"] = estimated_ingested_spans_usage
+        if estimated_rum_sessions_percentage is not unset:
+            kwargs["estimated_rum_sessions_percentage"] = estimated_rum_sessions_percentage
+        if estimated_rum_sessions_usage is not unset:
+            kwargs["estimated_rum_sessions_usage"] = estimated_rum_sessions_usage
         if fargate_percentage is not unset:
             kwargs["fargate_percentage"] = fargate_percentage
         if fargate_usage is not unset:
@@ -433,10 +453,6 @@ class MonthlyUsageAttributionValues(ModelNormal):
             kwargs["functions_percentage"] = functions_percentage
         if functions_usage is not unset:
             kwargs["functions_usage"] = functions_usage
-        if indexed_logs_percentage is not unset:
-            kwargs["indexed_logs_percentage"] = indexed_logs_percentage
-        if indexed_logs_usage is not unset:
-            kwargs["indexed_logs_usage"] = indexed_logs_usage
         if infra_host_percentage is not unset:
             kwargs["infra_host_percentage"] = infra_host_percentage
         if infra_host_usage is not unset:
