@@ -1,14 +1,28 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    none_type,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.toplist_widget_definition import ToplistWidgetDefinition
+    from datadog_api_client.v1.model.notebook_graph_size import NotebookGraphSize
+    from datadog_api_client.v1.model.notebook_split_by import NotebookSplitBy
+    from datadog_api_client.v1.model.notebook_cell_time import NotebookCellTime
+    from datadog_api_client.v1.model.notebook_relative_time import NotebookRelativeTime
+    from datadog_api_client.v1.model.notebook_absolute_time import NotebookAbsoluteTime
+
+
 class NotebookToplistCellAttributes(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -31,7 +45,14 @@ class NotebookToplistCellAttributes(ModelNormal):
         "time": "time",
     }
 
-    def __init__(self_, definition, *args, **kwargs):
+    def __init__(
+        self_,
+        definition: ToplistWidgetDefinition,
+        graph_size: Union[NotebookGraphSize, UnsetType] = unset,
+        split_by: Union[NotebookSplitBy, UnsetType] = unset,
+        time: Union[Union[NotebookCellTime, NotebookRelativeTime, NotebookAbsoluteTime], none_type, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         The attributes of a notebook ``toplist`` cell.
 
@@ -47,8 +68,12 @@ class NotebookToplistCellAttributes(ModelNormal):
         :param time: Timeframe for the notebook cell. When 'null', the notebook global time is used.
         :type time: NotebookCellTime, none_type, optional
         """
+        if graph_size is not unset:
+            kwargs["graph_size"] = graph_size
+        if split_by is not unset:
+            kwargs["split_by"] = split_by
+        if time is not unset:
+            kwargs["time"] = time
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.definition = definition
