@@ -1,15 +1,29 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     datetime,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.notebook_author import NotebookAuthor
+    from datadog_api_client.v1.model.notebook_cell_response import NotebookCellResponse
+    from datadog_api_client.v1.model.notebook_metadata import NotebookMetadata
+    from datadog_api_client.v1.model.notebook_status import NotebookStatus
+    from datadog_api_client.v1.model.notebook_global_time import NotebookGlobalTime
+    from datadog_api_client.v1.model.notebook_relative_time import NotebookRelativeTime
+    from datadog_api_client.v1.model.notebook_absolute_time import NotebookAbsoluteTime
+
+
 class NotebooksResponseDataAttributes(ModelNormal):
     validations = {
         "name": {
@@ -52,7 +66,18 @@ class NotebooksResponseDataAttributes(ModelNormal):
         "modified",
     }
 
-    def __init__(self_, name, *args, **kwargs):
+    def __init__(
+        self_,
+        name: str,
+        author: Union[NotebookAuthor, UnsetType] = unset,
+        cells: Union[List[NotebookCellResponse], UnsetType] = unset,
+        created: Union[datetime, UnsetType] = unset,
+        metadata: Union[NotebookMetadata, UnsetType] = unset,
+        modified: Union[datetime, UnsetType] = unset,
+        status: Union[NotebookStatus, UnsetType] = unset,
+        time: Union[NotebookGlobalTime, NotebookRelativeTime, NotebookAbsoluteTime, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         The attributes of a notebook in get all response.
 
@@ -80,8 +105,20 @@ class NotebooksResponseDataAttributes(ModelNormal):
         :param time: Notebook global timeframe.
         :type time: NotebookGlobalTime, optional
         """
+        if author is not unset:
+            kwargs["author"] = author
+        if cells is not unset:
+            kwargs["cells"] = cells
+        if created is not unset:
+            kwargs["created"] = created
+        if metadata is not unset:
+            kwargs["metadata"] = metadata
+        if modified is not unset:
+            kwargs["modified"] = modified
+        if status is not unset:
+            kwargs["status"] = status
+        if time is not unset:
+            kwargs["time"] = time
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.name = name
