@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -22,7 +26,9 @@ class NotebooksResponsePage(ModelNormal):
         "total_filtered_count": "total_filtered_count",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_, total_count: Union[int, UnsetType] = unset, total_filtered_count: Union[int, UnsetType] = unset, **kwargs
+    ):
         """
         Pagination metadata returned by the API.
 
@@ -32,6 +38,8 @@ class NotebooksResponsePage(ModelNormal):
         :param total_filtered_count: The total number of notebooks returned.
         :type total_filtered_count: int, optional
         """
+        if total_count is not unset:
+            kwargs["total_count"] = total_count
+        if total_filtered_count is not unset:
+            kwargs["total_filtered_count"] = total_filtered_count
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
