@@ -1,14 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.organization_billing import OrganizationBilling
+    from datadog_api_client.v1.model.organization_subscription import OrganizationSubscription
+
+
 class OrganizationCreateBody(ModelNormal):
     validations = {
         "name": {
@@ -33,7 +42,13 @@ class OrganizationCreateBody(ModelNormal):
         "subscription": "subscription",
     }
 
-    def __init__(self_, name, *args, **kwargs):
+    def __init__(
+        self_,
+        name: str,
+        billing: Union[OrganizationBilling, UnsetType] = unset,
+        subscription: Union[OrganizationSubscription, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Object describing an organization to create.
 
@@ -46,8 +61,10 @@ class OrganizationCreateBody(ModelNormal):
         :param subscription: Subscription definition. **Deprecated**.
         :type subscription: OrganizationSubscription, optional
         """
+        if billing is not unset:
+            kwargs["billing"] = billing
+        if subscription is not unset:
+            kwargs["subscription"] = subscription
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.name = name
