@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -20,7 +24,7 @@ class OrganizationSettingsSaml(ModelNormal):
         "enabled": "enabled",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(self_, enabled: Union[bool, UnsetType] = unset, **kwargs):
         """
         Set the boolean property enabled to enable or disable single sign on with SAML.
         See the SAML documentation for more information about all SAML settings.
@@ -28,6 +32,6 @@ class OrganizationSettingsSaml(ModelNormal):
         :param enabled: Whether or not SAML is enabled for this organization.
         :type enabled: bool, optional
         """
+        if enabled is not unset:
+            kwargs["enabled"] = enabled
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
