@@ -1,6 +1,7 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
 
 from datadog_api_client.model_utils import (
@@ -20,7 +21,7 @@ class PagerDutyServiceKey(ModelNormal):
         "service_key": "service_key",
     }
 
-    def __init__(self_, service_key, *args, **kwargs):
+    def __init__(self_, service_key: str, **kwargs):
         """
         PagerDuty service object key.
 
@@ -29,6 +30,4 @@ class PagerDutyServiceKey(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.service_key = service_key
