@@ -1,6 +1,7 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
 
 from datadog_api_client.model_utils import (
@@ -22,7 +23,7 @@ class ServiceLevelObjectiveQuery(ModelNormal):
         "numerator": "numerator",
     }
 
-    def __init__(self_, denominator, numerator, *args, **kwargs):
+    def __init__(self_, denominator: str, numerator: str, **kwargs):
         """
         A metric-based SLO. **Required if type is metric**. Note that Datadog only allows the sum by aggregator
         to be used because this will sum up all request counts instead of averaging them, or taking the max or
@@ -36,7 +37,5 @@ class ServiceLevelObjectiveQuery(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.denominator = denominator
         self_.numerator = numerator
