@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -22,7 +26,7 @@ class SignalAssigneeUpdateRequest(ModelNormal):
         "version": "version",
     }
 
-    def __init__(self_, assignee, *args, **kwargs):
+    def __init__(self_, assignee: str, version: Union[int, UnsetType] = unset, **kwargs):
         """
         Attributes describing an assignee update operation over a security signal.
 
@@ -32,8 +36,8 @@ class SignalAssigneeUpdateRequest(ModelNormal):
         :param version: Version of the updated signal. If server side version is higher, update will be rejected.
         :type version: int, optional
         """
+        if version is not unset:
+            kwargs["version"] = version
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.assignee = assignee
