@@ -1,14 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.slo_history_response_data import SLOHistoryResponseData
+    from datadog_api_client.v1.model.slo_history_response_error import SLOHistoryResponseError
+
+
 class SLOHistoryResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -25,7 +34,12 @@ class SLOHistoryResponse(ModelNormal):
         "errors": "errors",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        data: Union[SLOHistoryResponseData, UnsetType] = unset,
+        errors: Union[List[SLOHistoryResponseError], UnsetType] = unset,
+        **kwargs,
+    ):
         """
         A service level objective history response.
 
@@ -35,6 +49,8 @@ class SLOHistoryResponse(ModelNormal):
         :param errors: A list of errors while querying the history data for the service level objective.
         :type errors: [SLOHistoryResponseError], optional
         """
+        if data is not unset:
+            kwargs["data"] = data
+        if errors is not unset:
+            kwargs["errors"] = errors
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
