@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -29,7 +33,7 @@ class SLOListWidgetQuery(ModelNormal):
         "query_string": "query_string",
     }
 
-    def __init__(self_, query_string, *args, **kwargs):
+    def __init__(self_, query_string: str, limit: Union[int, UnsetType] = unset, **kwargs):
         """
         Updated SLO List widget.
 
@@ -39,8 +43,8 @@ class SLOListWidgetQuery(ModelNormal):
         :param query_string: Widget query.
         :type query_string: str
         """
+        if limit is not unset:
+            kwargs["limit"] = limit
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.query_string = query_string
