@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,11 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.slo_list_widget_query import SLOListWidgetQuery
+    from datadog_api_client.v1.model.slo_list_widget_request_type import SLOListWidgetRequestType
+
+
 class SLOListWidgetRequest(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -25,7 +32,7 @@ class SLOListWidgetRequest(ModelNormal):
         "request_type": "request_type",
     }
 
-    def __init__(self_, query, request_type, *args, **kwargs):
+    def __init__(self_, query: SLOListWidgetQuery, request_type: SLOListWidgetRequestType, **kwargs):
         """
         Updated SLO List widget.
 
@@ -37,7 +44,5 @@ class SLOListWidgetRequest(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.query = query
         self_.request_type = request_type
