@@ -1,14 +1,26 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.synthetics_global_variable_attributes import SyntheticsGlobalVariableAttributes
+    from datadog_api_client.v1.model.synthetics_global_variable_parse_test_options import (
+        SyntheticsGlobalVariableParseTestOptions,
+    )
+    from datadog_api_client.v1.model.synthetics_global_variable_value import SyntheticsGlobalVariableValue
+
+
 class SyntheticsGlobalVariable(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -43,7 +55,18 @@ class SyntheticsGlobalVariable(ModelNormal):
         "id",
     }
 
-    def __init__(self_, description, name, tags, value, *args, **kwargs):
+    def __init__(
+        self_,
+        description: str,
+        name: str,
+        tags: List[str],
+        value: SyntheticsGlobalVariableValue,
+        attributes: Union[SyntheticsGlobalVariableAttributes, UnsetType] = unset,
+        id: Union[str, UnsetType] = unset,
+        parse_test_options: Union[SyntheticsGlobalVariableParseTestOptions, UnsetType] = unset,
+        parse_test_public_id: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Synthetics global variable.
 
@@ -71,10 +94,16 @@ class SyntheticsGlobalVariable(ModelNormal):
         :param value: Value of the global variable.
         :type value: SyntheticsGlobalVariableValue
         """
+        if attributes is not unset:
+            kwargs["attributes"] = attributes
+        if id is not unset:
+            kwargs["id"] = id
+        if parse_test_options is not unset:
+            kwargs["parse_test_options"] = parse_test_options
+        if parse_test_public_id is not unset:
+            kwargs["parse_test_public_id"] = parse_test_public_id
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.description = description
         self_.name = name
         self_.tags = tags
