@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,10 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.synthetics_warning_type import SyntheticsWarningType
+
+
 class SyntheticsStepDetailWarning(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -24,7 +30,7 @@ class SyntheticsStepDetailWarning(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, message, type, *args, **kwargs):
+    def __init__(self_, message: str, type: SyntheticsWarningType, **kwargs):
         """
         Object collecting warnings for a given step.
 
@@ -36,7 +42,5 @@ class SyntheticsStepDetailWarning(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.message = message
         self_.type = type
