@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -27,7 +31,7 @@ class SyntheticsTestOptionsMonitorOptions(ModelNormal):
         "renotify_interval": "renotify_interval",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(self_, renotify_interval: Union[int, UnsetType] = unset, **kwargs):
         """
         Object containing the options for a Synthetic test as a monitor
         (for example, renotification).
@@ -36,6 +40,6 @@ class SyntheticsTestOptionsMonitorOptions(ModelNormal):
             (in minutes).
         :type renotify_interval: int, optional
         """
+        if renotify_interval is not unset:
+            kwargs["renotify_interval"] = renotify_interval
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
