@@ -1,12 +1,16 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     datetime,
+    unset,
+    UnsetType,
 )
 
 
@@ -27,7 +31,14 @@ class UsageAuditLogsHour(ModelNormal):
         "public_id": "public_id",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        hour: Union[datetime, UnsetType] = unset,
+        lines_indexed: Union[int, UnsetType] = unset,
+        org_name: Union[str, UnsetType] = unset,
+        public_id: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Audit logs usage for a given organization for a given hour.
 
@@ -43,6 +54,12 @@ class UsageAuditLogsHour(ModelNormal):
         :param public_id: The organization public ID.
         :type public_id: str, optional
         """
+        if hour is not unset:
+            kwargs["hour"] = hour
+        if lines_indexed is not unset:
+            kwargs["lines_indexed"] = lines_indexed
+        if org_name is not unset:
+            kwargs["org_name"] = org_name
+        if public_id is not unset:
+            kwargs["public_id"] = public_id
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
