@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -20,13 +24,13 @@ class UserDisableResponse(ModelNormal):
         "message": "message",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(self_, message: Union[str, UnsetType] = unset, **kwargs):
         """
         Array of user disabled for a given organization.
 
         :param message: Information pertaining to a user disabled for a given organization.
         :type message: str, optional
         """
+        if message is not unset:
+            kwargs["message"] = message
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
