@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -43,7 +47,9 @@ class WidgetLayout(ModelNormal):
         "y": "y",
     }
 
-    def __init__(self_, height, width, x, y, *args, **kwargs):
+    def __init__(
+        self_, height: int, width: int, x: int, y: int, is_column_break: Union[bool, UnsetType] = unset, **kwargs
+    ):
         """
         The layout for a widget on a ``free`` or **new dashboard layout** dashboard.
 
@@ -63,10 +69,10 @@ class WidgetLayout(ModelNormal):
         :param y: The position of the widget on the y (vertical) axis. Should be a non-negative integer.
         :type y: int
         """
+        if is_column_break is not unset:
+            kwargs["is_column_break"] = is_column_break
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.height = height
         self_.width = width
         self_.x = x
