@@ -204,6 +204,9 @@ from datadog_api_client.v1.model.image_widget_definition_type import ImageWidget
 from datadog_api_client.v1.model.intake_payload_accepted import IntakePayloadAccepted
 from datadog_api_client.v1.model.list_stream_column import ListStreamColumn
 from datadog_api_client.v1.model.list_stream_column_width import ListStreamColumnWidth
+from datadog_api_client.v1.model.list_stream_compute_aggregation import ListStreamComputeAggregation
+from datadog_api_client.v1.model.list_stream_compute_items import ListStreamComputeItems
+from datadog_api_client.v1.model.list_stream_group_by_items import ListStreamGroupByItems
 from datadog_api_client.v1.model.list_stream_query import ListStreamQuery
 from datadog_api_client.v1.model.list_stream_response_format import ListStreamResponseFormat
 from datadog_api_client.v1.model.list_stream_source import ListStreamSource
@@ -314,6 +317,7 @@ from datadog_api_client.v1.model.monitor_group_search_response_counts import Mon
 from datadog_api_client.v1.model.monitor_group_search_result import MonitorGroupSearchResult
 from datadog_api_client.v1.model.monitor_options import MonitorOptions
 from datadog_api_client.v1.model.monitor_options_aggregation import MonitorOptionsAggregation
+from datadog_api_client.v1.model.monitor_options_notification_presets import MonitorOptionsNotificationPresets
 from datadog_api_client.v1.model.monitor_options_scheduling_options import MonitorOptionsSchedulingOptions
 from datadog_api_client.v1.model.monitor_options_scheduling_options_evaluation_window import (
     MonitorOptionsSchedulingOptionsEvaluationWindow,
@@ -415,6 +419,9 @@ from datadog_api_client.v1.model.query_value_widget_definition_type import Query
 from datadog_api_client.v1.model.query_value_widget_request import QueryValueWidgetRequest
 from datadog_api_client.v1.model.reference_table_logs_lookup_processor import ReferenceTableLogsLookupProcessor
 from datadog_api_client.v1.model.response_meta_attributes import ResponseMetaAttributes
+from datadog_api_client.v1.model.run_workflow_widget_definition import RunWorkflowWidgetDefinition
+from datadog_api_client.v1.model.run_workflow_widget_definition_type import RunWorkflowWidgetDefinitionType
+from datadog_api_client.v1.model.run_workflow_widget_input import RunWorkflowWidgetInput
 from datadog_api_client.v1.model.slo_bulk_delete import SLOBulkDelete
 from datadog_api_client.v1.model.slo_bulk_delete_error import SLOBulkDeleteError
 from datadog_api_client.v1.model.slo_bulk_delete_response import SLOBulkDeleteResponse
@@ -606,6 +613,7 @@ from datadog_api_client.v1.model.synthetics_get_browser_test_latest_results_resp
 )
 from datadog_api_client.v1.model.synthetics_global_variable import SyntheticsGlobalVariable
 from datadog_api_client.v1.model.synthetics_global_variable_attributes import SyntheticsGlobalVariableAttributes
+from datadog_api_client.v1.model.synthetics_global_variable_options import SyntheticsGlobalVariableOptions
 from datadog_api_client.v1.model.synthetics_global_variable_parse_test_options import (
     SyntheticsGlobalVariableParseTestOptions,
 )
@@ -613,6 +621,9 @@ from datadog_api_client.v1.model.synthetics_global_variable_parse_test_options_t
     SyntheticsGlobalVariableParseTestOptionsType,
 )
 from datadog_api_client.v1.model.synthetics_global_variable_parser_type import SyntheticsGlobalVariableParserType
+from datadog_api_client.v1.model.synthetics_global_variable_totp_parameters import (
+    SyntheticsGlobalVariableTOTPParameters,
+)
 from datadog_api_client.v1.model.synthetics_global_variable_value import SyntheticsGlobalVariableValue
 from datadog_api_client.v1.model.synthetics_list_global_variables_response import SyntheticsListGlobalVariablesResponse
 from datadog_api_client.v1.model.synthetics_list_tests_response import SyntheticsListTestsResponse
@@ -655,8 +666,13 @@ from datadog_api_client.v1.model.synthetics_test_headers import SyntheticsTestHe
 from datadog_api_client.v1.model.synthetics_test_metadata import SyntheticsTestMetadata
 from datadog_api_client.v1.model.synthetics_test_monitor_status import SyntheticsTestMonitorStatus
 from datadog_api_client.v1.model.synthetics_test_options import SyntheticsTestOptions
+from datadog_api_client.v1.model.synthetics_test_options_http_version import SyntheticsTestOptionsHTTPVersion
 from datadog_api_client.v1.model.synthetics_test_options_monitor_options import SyntheticsTestOptionsMonitorOptions
 from datadog_api_client.v1.model.synthetics_test_options_retry import SyntheticsTestOptionsRetry
+from datadog_api_client.v1.model.synthetics_test_options_scheduling import SyntheticsTestOptionsScheduling
+from datadog_api_client.v1.model.synthetics_test_options_scheduling_timeframe import (
+    SyntheticsTestOptionsSchedulingTimeframe,
+)
 from datadog_api_client.v1.model.synthetics_test_pause_status import SyntheticsTestPauseStatus
 from datadog_api_client.v1.model.synthetics_test_process_status import SyntheticsTestProcessStatus
 from datadog_api_client.v1.model.synthetics_test_request import SyntheticsTestRequest
