@@ -7,6 +7,7 @@ import collections
 from typing import Any, Dict, Union
 
 from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.configuration import Configuration
 from datadog_api_client.model_utils import (
     datetime,
     set_attribute_from_path,
@@ -55,7 +56,7 @@ class SecurityMonitoringApi:
 
     def __init__(self, api_client=None):
         if api_client is None:
-            api_client = ApiClient()
+            api_client = ApiClient(Configuration())
         self.api_client = api_client
 
         self._create_security_filter_endpoint = _Endpoint(
