@@ -7,6 +7,7 @@ from typing import Any, Dict, Union
 import warnings
 
 from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.configuration import Configuration
 from datadog_api_client.model_utils import (
     datetime,
     UnsetType,
@@ -37,7 +38,7 @@ class UsageMeteringApi:
 
     def __init__(self, api_client=None):
         if api_client is None:
-            api_client = ApiClient()
+            api_client = ApiClient(Configuration())
         self.api_client = api_client
 
         self._get_cost_by_org_endpoint = _Endpoint(
