@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -20,7 +22,7 @@ class APIErrorResponse(ModelNormal):
         "errors": "errors",
     }
 
-    def __init__(self_, errors, *args, **kwargs):
+    def __init__(self_, errors: List[str], **kwargs):
         """
         API error response.
 
@@ -29,6 +31,4 @@ class APIErrorResponse(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.errors = errors
