@@ -1,6 +1,7 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
 
 from datadog_api_client.model_utils import (
@@ -10,7 +11,7 @@ from datadog_api_client.model_utils import (
 
 
 class ApplicationKeyResponseIncludedItem(ModelComposed):
-    def __init__(self_, *args, **kwargs):
+    def __init__(self, **kwargs):
         """
         An object related to an application key.
 
@@ -28,8 +29,6 @@ class ApplicationKeyResponseIncludedItem(ModelComposed):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
     @cached_property
     def _composed_schemas(_):
         # we need this here to make our import statements work
