@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -28,7 +32,7 @@ class EventsRequestPage(ModelNormal):
         "limit": "limit",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(self_, cursor: Union[str, UnsetType] = unset, limit: Union[int, UnsetType] = unset, **kwargs):
         """
         Pagination settings.
 
@@ -38,6 +42,8 @@ class EventsRequestPage(ModelNormal):
         :param limit: The maximum number of logs in the response.
         :type limit: int, optional
         """
+        if cursor is not unset:
+            kwargs["cursor"] = cursor
+        if limit is not unset:
+            kwargs["limit"] = limit
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
