@@ -1,14 +1,24 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.incident_service_response_attributes import IncidentServiceResponseAttributes
+    from datadog_api_client.v2.model.incident_service_relationships import IncidentServiceRelationships
+    from datadog_api_client.v2.model.incident_service_type import IncidentServiceType
+
+
 class IncidentServiceResponseData(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -33,7 +43,14 @@ class IncidentServiceResponseData(ModelNormal):
         "relationships",
     }
 
-    def __init__(self_, id, type, *args, **kwargs):
+    def __init__(
+        self_,
+        id: str,
+        type: IncidentServiceType,
+        attributes: Union[IncidentServiceResponseAttributes, UnsetType] = unset,
+        relationships: Union[IncidentServiceRelationships, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Incident Service data from responses.
 
@@ -49,9 +66,11 @@ class IncidentServiceResponseData(ModelNormal):
         :param type: Incident service resource type.
         :type type: IncidentServiceType
         """
+        if attributes is not unset:
+            kwargs["attributes"] = attributes
+        if relationships is not unset:
+            kwargs["relationships"] = relationships
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.id = id
         self_.type = type
