@@ -1,14 +1,22 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.relationship_to_user import RelationshipToUser
+
+
 class IncidentTeamRelationships(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -24,7 +32,12 @@ class IncidentTeamRelationships(ModelNormal):
         "last_modified_by": "last_modified_by",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        created_by: Union[RelationshipToUser, UnsetType] = unset,
+        last_modified_by: Union[RelationshipToUser, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         The incident team's relationships.
 
@@ -34,6 +47,8 @@ class IncidentTeamRelationships(ModelNormal):
         :param last_modified_by: Relationship to user.
         :type last_modified_by: RelationshipToUser, optional
         """
+        if created_by is not unset:
+            kwargs["created_by"] = created_by
+        if last_modified_by is not unset:
+            kwargs["last_modified_by"] = last_modified_by
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
