@@ -1,16 +1,29 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Dict, List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     datetime,
     none_type,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.incident_field_attributes import IncidentFieldAttributes
+    from datadog_api_client.v2.model.incident_notification_handle import IncidentNotificationHandle
+    from datadog_api_client.v2.model.incident_field_attributes_single_value import IncidentFieldAttributesSingleValue
+    from datadog_api_client.v2.model.incident_field_attributes_multiple_value import (
+        IncidentFieldAttributesMultipleValue,
+    )
+
+
 class IncidentUpdateAttributes(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -25,7 +38,6 @@ class IncidentUpdateAttributes(ModelNormal):
             "detected": (datetime, none_type),
             "fields": ({str: (IncidentFieldAttributes,)},),
             "notification_handles": ([IncidentNotificationHandle],),
-            "resolved": (datetime, none_type),
             "title": (str,),
         }
 
@@ -37,11 +49,29 @@ class IncidentUpdateAttributes(ModelNormal):
         "detected": "detected",
         "fields": "fields",
         "notification_handles": "notification_handles",
-        "resolved": "resolved",
         "title": "title",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        customer_impact_end: Union[datetime, none_type, UnsetType] = unset,
+        customer_impact_scope: Union[str, UnsetType] = unset,
+        customer_impact_start: Union[datetime, none_type, UnsetType] = unset,
+        customer_impacted: Union[bool, UnsetType] = unset,
+        detected: Union[datetime, none_type, UnsetType] = unset,
+        fields: Union[
+            Dict[
+                str,
+                Union[
+                    IncidentFieldAttributes, IncidentFieldAttributesSingleValue, IncidentFieldAttributesMultipleValue
+                ],
+            ],
+            UnsetType,
+        ] = unset,
+        notification_handles: Union[List[IncidentNotificationHandle], UnsetType] = unset,
+        title: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         The incident's attributes for an update request.
 
@@ -66,12 +96,23 @@ class IncidentUpdateAttributes(ModelNormal):
         :param notification_handles: Notification handles that will be notified of the incident during update.
         :type notification_handles: [IncidentNotificationHandle], optional
 
-        :param resolved: Timestamp when the incident's state was set to resolved.
-        :type resolved: datetime, none_type, optional
-
         :param title: The title of the incident, which summarizes what happened.
         :type title: str, optional
         """
+        if customer_impact_end is not unset:
+            kwargs["customer_impact_end"] = customer_impact_end
+        if customer_impact_scope is not unset:
+            kwargs["customer_impact_scope"] = customer_impact_scope
+        if customer_impact_start is not unset:
+            kwargs["customer_impact_start"] = customer_impact_start
+        if customer_impacted is not unset:
+            kwargs["customer_impacted"] = customer_impacted
+        if detected is not unset:
+            kwargs["detected"] = detected
+        if fields is not unset:
+            kwargs["fields"] = fields
+        if notification_handles is not unset:
+            kwargs["notification_handles"] = notification_handles
+        if title is not unset:
+            kwargs["title"] = title
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
