@@ -1,6 +1,7 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
 
 from datadog_api_client.model_utils import (
@@ -22,7 +23,7 @@ class LogsArchiveIntegrationGCS(ModelNormal):
         "project_id": "project_id",
     }
 
-    def __init__(self_, client_email, project_id, *args, **kwargs):
+    def __init__(self_, client_email: str, project_id: str, **kwargs):
         """
         The GCS archive's integration destination.
 
@@ -34,7 +35,5 @@ class LogsArchiveIntegrationGCS(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.client_email = client_email
         self_.project_id = project_id
