@@ -1,14 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.logs_metric_response_attributes import LogsMetricResponseAttributes
+    from datadog_api_client.v2.model.logs_metric_type import LogsMetricType
+
+
 class LogsMetricResponseData(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -27,7 +36,13 @@ class LogsMetricResponseData(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        attributes: Union[LogsMetricResponseAttributes, UnsetType] = unset,
+        id: Union[str, UnsetType] = unset,
+        type: Union[LogsMetricType, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         The log-based metric properties.
 
@@ -40,6 +55,10 @@ class LogsMetricResponseData(ModelNormal):
         :param type: The type of the resource. The value should always be logs_metrics.
         :type type: LogsMetricType, optional
         """
+        if attributes is not unset:
+            kwargs["attributes"] = attributes
+        if id is not unset:
+            kwargs["id"] = id
+        if type is not unset:
+            kwargs["type"] = type
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
