@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -20,7 +24,7 @@ class LogsResponseMetadataPage(ModelNormal):
         "after": "after",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(self_, after: Union[str, UnsetType] = unset, **kwargs):
         """
         Paging attributes.
 
@@ -28,6 +32,6 @@ class LogsResponseMetadataPage(ModelNormal):
             parameters with the addition of the ``page[cursor]``.
         :type after: str, optional
         """
+        if after is not unset:
+            kwargs["after"] = after
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
