@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -20,13 +24,13 @@ class MetricAllTagsAttributes(ModelNormal):
         "tags": "tags",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(self_, tags: Union[List[str], UnsetType] = unset, **kwargs):
         """
         Object containing the definition of a metric's tags.
 
         :param tags: List of indexed tag value pairs.
         :type tags: [str], optional
         """
+        if tags is not unset:
+            kwargs["tags"] = tags
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
