@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,11 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.opsgenie_service_response_attributes import OpsgenieServiceResponseAttributes
+    from datadog_api_client.v2.model.opsgenie_service_type import OpsgenieServiceType
+
+
 class OpsgenieServiceResponseData(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -27,7 +34,7 @@ class OpsgenieServiceResponseData(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, attributes, id, type, *args, **kwargs):
+    def __init__(self_, attributes: OpsgenieServiceResponseAttributes, id: str, type: OpsgenieServiceType, **kwargs):
         """
         Opsgenie service data from a response.
 
@@ -42,8 +49,6 @@ class OpsgenieServiceResponseData(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.attributes = attributes
         self_.id = id
         self_.type = type
