@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -38,7 +42,14 @@ class PartialAPIKeyAttributes(ModelNormal):
         "modified_at",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        created_at: Union[str, UnsetType] = unset,
+        last4: Union[str, UnsetType] = unset,
+        modified_at: Union[str, UnsetType] = unset,
+        name: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Attributes of a partial API key.
 
@@ -54,6 +65,12 @@ class PartialAPIKeyAttributes(ModelNormal):
         :param name: Name of the API key.
         :type name: str, optional
         """
+        if created_at is not unset:
+            kwargs["created_at"] = created_at
+        if last4 is not unset:
+            kwargs["last4"] = last4
+        if modified_at is not unset:
+            kwargs["modified_at"] = modified_at
+        if name is not unset:
+            kwargs["name"] = name
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
