@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -29,7 +33,7 @@ class ProcessSummariesMetaPage(ModelNormal):
         "size": "size",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(self_, after: Union[str, UnsetType] = unset, size: Union[int, UnsetType] = unset, **kwargs):
         """
         Paging attributes.
 
@@ -40,6 +44,8 @@ class ProcessSummariesMetaPage(ModelNormal):
         :param size: Number of results returned.
         :type size: int, optional
         """
+        if after is not unset:
+            kwargs["after"] = after
+        if size is not unset:
+            kwargs["size"] = size
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
