@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,12 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.relationship_to_incident_attachment_data import (
+        RelationshipToIncidentAttachmentData,
+    )
+
+
 class RelationshipToIncidentAttachment(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -24,7 +32,7 @@ class RelationshipToIncidentAttachment(ModelNormal):
         "data": "data",
     }
 
-    def __init__(self_, data, *args, **kwargs):
+    def __init__(self_, data: List[RelationshipToIncidentAttachmentData], **kwargs):
         """
         A relationship reference for attachments.
 
@@ -33,6 +41,4 @@ class RelationshipToIncidentAttachment(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.data = data
