@@ -1,14 +1,22 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.roles_type import RolesType
+
+
 class RelationshipToRoleData(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -24,7 +32,7 @@ class RelationshipToRoleData(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(self_, id: Union[str, UnsetType] = unset, type: Union[RolesType, UnsetType] = unset, **kwargs):
         """
         Relationship to role object.
 
@@ -34,6 +42,8 @@ class RelationshipToRoleData(ModelNormal):
         :param type: Roles type.
         :type type: RolesType, optional
         """
+        if id is not unset:
+            kwargs["id"] = id
+        if type is not unset:
+            kwargs["type"] = type
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
