@@ -1,14 +1,24 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.role_create_attributes import RoleCreateAttributes
+    from datadog_api_client.v2.model.role_response_relationships import RoleResponseRelationships
+    from datadog_api_client.v2.model.roles_type import RolesType
+
+
 class RoleCreateResponseData(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -30,7 +40,14 @@ class RoleCreateResponseData(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, type, *args, **kwargs):
+    def __init__(
+        self_,
+        type: RolesType,
+        attributes: Union[RoleCreateAttributes, UnsetType] = unset,
+        id: Union[str, UnsetType] = unset,
+        relationships: Union[RoleResponseRelationships, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Role object returned by the API.
 
@@ -46,8 +63,12 @@ class RoleCreateResponseData(ModelNormal):
         :param type: Roles type.
         :type type: RolesType
         """
+        if attributes is not unset:
+            kwargs["attributes"] = attributes
+        if id is not unset:
+            kwargs["id"] = id
+        if relationships is not unset:
+            kwargs["relationships"] = relationships
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.type = type
