@@ -1,12 +1,16 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     datetime,
+    unset,
+    UnsetType,
 )
 
 
@@ -29,7 +33,13 @@ class RoleUpdateAttributes(ModelNormal):
         "modified_at",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        created_at: Union[datetime, UnsetType] = unset,
+        modified_at: Union[datetime, UnsetType] = unset,
+        name: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Attributes of the role.
 
@@ -42,6 +52,10 @@ class RoleUpdateAttributes(ModelNormal):
         :param name: Name of the role.
         :type name: str, optional
         """
+        if created_at is not unset:
+            kwargs["created_at"] = created_at
+        if modified_at is not unset:
+            kwargs["modified_at"] = modified_at
+        if name is not unset:
+            kwargs["name"] = name
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
