@@ -1,12 +1,16 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     datetime,
+    unset,
+    UnsetType,
 )
 
 
@@ -23,7 +27,7 @@ class RUMAggregateBucketValueTimeseriesPoint(ModelNormal):
         "value": "value",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(self_, time: Union[datetime, UnsetType] = unset, value: Union[float, UnsetType] = unset, **kwargs):
         """
         A timeseries point.
 
@@ -33,6 +37,8 @@ class RUMAggregateBucketValueTimeseriesPoint(ModelNormal):
         :param value: The value for this point.
         :type value: float, optional
         """
+        if time is not unset:
+            kwargs["time"] = time
+        if value is not unset:
+            kwargs["value"] = value
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
