@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -22,7 +26,7 @@ class RUMApplicationCreateAttributes(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, name, *args, **kwargs):
+    def __init__(self_, name: str, type: Union[str, UnsetType] = unset, **kwargs):
         """
         RUM application creation attributes.
 
@@ -32,8 +36,8 @@ class RUMApplicationCreateAttributes(ModelNormal):
         :param type: Type of the RUM application. Supported values are ``browser`` , ``ios`` , ``android`` , ``react-native`` , ``flutter``.
         :type type: str, optional
         """
+        if type is not unset:
+            kwargs["type"] = type
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.name = name
