@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Any, Dict, List, Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,8 @@ from datadog_api_client.model_utils import (
     date,
     datetime,
     none_type,
+    unset,
+    UnsetType,
 )
 
 
@@ -43,7 +47,14 @@ class RUMEventAttributes(ModelNormal):
         "timestamp": "timestamp",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        attributes: Union[Dict[str, Any], UnsetType] = unset,
+        service: Union[str, UnsetType] = unset,
+        tags: Union[List[str], UnsetType] = unset,
+        timestamp: Union[datetime, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         JSON object containing all event attributes and their associated values.
 
@@ -61,6 +72,12 @@ class RUMEventAttributes(ModelNormal):
         :param timestamp: Timestamp of your event.
         :type timestamp: datetime, optional
         """
+        if attributes is not unset:
+            kwargs["attributes"] = attributes
+        if service is not unset:
+            kwargs["service"] = service
+        if tags is not unset:
+            kwargs["tags"] = tags
+        if timestamp is not unset:
+            kwargs["timestamp"] = timestamp
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
