@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -22,7 +26,7 @@ class RUMQueryOptions(ModelNormal):
         "timezone": "timezone",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(self_, time_offset: Union[int, UnsetType] = unset, timezone: Union[str, UnsetType] = unset, **kwargs):
         """
         Global query options that are used during the query.
         Note: Only supply timezone or time offset, not both. Otherwise, the query fails.
@@ -30,9 +34,11 @@ class RUMQueryOptions(ModelNormal):
         :param time_offset: The time offset (in seconds) to apply to the query.
         :type time_offset: int, optional
 
-        :param timezone: The timezone can be specified both as an offset, for example: "UTC+03:00".
+        :param timezone: The timezone can be specified as GMT, UTC, an offset from UTC (like UTC+1), or as a Timezone Database identifier (like America/New_York).
         :type timezone: str, optional
         """
+        if time_offset is not unset:
+            kwargs["time_offset"] = time_offset
+        if timezone is not unset:
+            kwargs["timezone"] = timezone
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
