@@ -1,14 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.saml_assertion_attribute_attributes import SAMLAssertionAttributeAttributes
+    from datadog_api_client.v2.model.saml_assertion_attributes_type import SAMLAssertionAttributesType
+
+
 class SAMLAssertionAttribute(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -27,7 +36,13 @@ class SAMLAssertionAttribute(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, id, type, *args, **kwargs):
+    def __init__(
+        self_,
+        id: str,
+        type: SAMLAssertionAttributesType,
+        attributes: Union[SAMLAssertionAttributeAttributes, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         SAML assertion attribute.
 
@@ -40,9 +55,9 @@ class SAMLAssertionAttribute(ModelNormal):
         :param type: SAML assertion attributes resource type.
         :type type: SAMLAssertionAttributesType
         """
+        if attributes is not unset:
+            kwargs["attributes"] = attributes
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.id = id
         self_.type = type
