@@ -43,6 +43,7 @@ class SecurityMonitoringStandardRuleResponse(ModelNormal):
             "compliance_signal_options": (CloudConfigurationRuleComplianceSignalOptions,),
             "created_at": (int,),
             "creation_author_id": (int,),
+            "deprecation_date": (int,),
             "filters": ([SecurityMonitoringFilter],),
             "has_extended_title": (bool,),
             "id": (str,),
@@ -64,6 +65,7 @@ class SecurityMonitoringStandardRuleResponse(ModelNormal):
         "compliance_signal_options": "complianceSignalOptions",
         "created_at": "createdAt",
         "creation_author_id": "creationAuthorId",
+        "deprecation_date": "deprecationDate",
         "filters": "filters",
         "has_extended_title": "hasExtendedTitle",
         "id": "id",
@@ -86,6 +88,7 @@ class SecurityMonitoringStandardRuleResponse(ModelNormal):
         compliance_signal_options: Union[CloudConfigurationRuleComplianceSignalOptions, UnsetType] = unset,
         created_at: Union[int, UnsetType] = unset,
         creation_author_id: Union[int, UnsetType] = unset,
+        deprecation_date: Union[int, UnsetType] = unset,
         filters: Union[List[SecurityMonitoringFilter], UnsetType] = unset,
         has_extended_title: Union[bool, UnsetType] = unset,
         id: Union[str, UnsetType] = unset,
@@ -117,6 +120,9 @@ class SecurityMonitoringStandardRuleResponse(ModelNormal):
         :param creation_author_id: User ID of the user who created the rule.
         :type creation_author_id: int, optional
 
+        :param deprecation_date: When the rule will be deprecated, timestamp in milliseconds.
+        :type deprecation_date: int, optional
+
         :param filters: Additional queries to filter matched events before they are processed.
         :type filters: [SecurityMonitoringFilter], optional
 
@@ -167,6 +173,8 @@ class SecurityMonitoringStandardRuleResponse(ModelNormal):
             kwargs["created_at"] = created_at
         if creation_author_id is not unset:
             kwargs["creation_author_id"] = creation_author_id
+        if deprecation_date is not unset:
+            kwargs["deprecation_date"] = deprecation_date
         if filters is not unset:
             kwargs["filters"] = filters
         if has_extended_title is not unset:
