@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -26,7 +30,14 @@ class SecurityMonitoringTriageUser(ModelNormal):
         "uuid": "uuid",
     }
 
-    def __init__(self_, uuid, *args, **kwargs):
+    def __init__(
+        self_,
+        uuid: str,
+        handle: Union[str, UnsetType] = unset,
+        id: Union[int, UnsetType] = unset,
+        name: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Object representing a given user entity.
 
@@ -42,8 +53,12 @@ class SecurityMonitoringTriageUser(ModelNormal):
         :param uuid: UUID assigned by Datadog to this user account.
         :type uuid: str
         """
+        if handle is not unset:
+            kwargs["handle"] = handle
+        if id is not unset:
+            kwargs["id"] = id
+        if name is not unset:
+            kwargs["name"] = name
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.uuid = uuid
