@@ -1,14 +1,22 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.user_invitation_response_data import UserInvitationResponseData
+
+
 class UserInvitationsResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -22,13 +30,13 @@ class UserInvitationsResponse(ModelNormal):
         "data": "data",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(self_, data: Union[List[UserInvitationResponseData], UnsetType] = unset, **kwargs):
         """
         User invitations as returned by the API.
 
         :param data: Array of user invitations.
         :type data: [UserInvitationResponseData], optional
         """
+        if data is not unset:
+            kwargs["data"] = data
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
